<h1 align=center>NEORICK</h1>

<div align=center>
  
  ![Project Status](https://img.shields.io/badge/status-Em%20andamento-yellow)
  ![versão](https://img.shields.io/badge/versão-1.0.0-important)
  
</div>

> [!WARNING]
> O uso dos arquivos deste projeto é delimitado para <strong>fins de estudo</strong>. Caso queira colaborar com o desenvolvimento, entre no [site](https://neorick-net.vercel.app) e contate-nos.

> Caso ainda não tenha o Python instalado, baixe [aqui.](https://www.python.org/downloads)

# Requisitos

1. Python 3.10 ou superior

# Uso do código fonte

Você pode clonar o repositório ou baixar o arquivo `.tar.gz` no site do [NeoRick](https://neorick-net.vercel.app)

Caso queira prosseguir com a opção 1:

1. Clone o repositório de entre nele

```sh
git clone https://github.com/Rickzinho3/neorick.git
cd neorick
```

2. Instale as dependências

```sh
poetry install
```

# Extra

Caso queira que o `Neorich` seja executado no seu powershell, siga os seguintes passos:

1. Instale a biblioteca

```sh
pip install neorick
```

2. Abra o `Powershell` e digite o comando `notepad $PROFILE`

> [!NOTE]
> Caso você não tenha um perfil, irá aparecer uma mensagem para você criar, basta confirmar.

Depois de abrir o seu perfil, cole `neorick` e salve.
<br>

<p align=center>J. Henrique &copy; 2025. Todos os direitos reservados.</p>
